{$ ctrl.nameLabel $} ( {$ ctrl.typeLabel $} )

#### Generic Table View:

Names:

- {$ label $}

List Function: {$ ctrl.listFunctionNameLabel $}
Properties:

- {$ label $}

Table Columns:

- {$ label $}

Summary Template URL: {$ ctrl.summaryTemplateUrl $}

#### Supports Details View:

Load Function: {$ ctrl.loadFunctionNameLabel $}
Details Views:

- {$ label $}

{$ ctrl.detailsViewsLabel $}

#### Global Actions:

{$ action.template.text $}

#### Batch Actions:

{$ action.template.text $}

#### Item Actions:

{$ action.template.text $}